<?php 
namespace Concrete\Package\CcOptinFree\Controllers;

use Page;
use Loader;

use Concrete\Package\CcOptinFree\CcOptinDate;
use Concrete\Package\CcOptinFree\Controllers\CcOptinVal;
use Concrete\Package\CcOptinFree\CcOptinActiveCampaigns;
use Concrete\Package\CcOptinFree\CcOptinCampaignTracker;

use Concrete\Package\CcOptinFree\Models\CcOptinCampaign;
use Concrete\Package\CcOptinFree\Models\CcOptinSubscriber;

/**
* Data posted from a campaign form is sent here. Returns submitActions if success, 
* normal validation if it fails.
*/
class SubscribeController extends CcOptinController
{
	private $db;

	public function __construct() {
		parent::__construct(__FILE__);
		$this->db = Loader::db();
	}

	protected function post($post) {
		$result = array();

		$cID = intval($_GET['cID']);
		$id = intval($_GET['id']);

		if(!$cID || !$id) return $this->outputJsonError(t('No page or campaign specified.'));

		$val = new CcOptinVal($post, $result);

		// Validate fields first to save some processing
		$email = $val->test('email', FILTER_VALIDATE_EMAIL);
		if(!$email) {
			return $this->outputJsonError(t('You have entered an invalid email address.'));
		}


		$ac = new CcOptinActiveCampaigns(Page::getByID($cID));
		$IDs = $ac->get();

		if(!in_array($id, $IDs)) return $this->outputJsonError(t('This campaign is not active.'));
		
		$th = Loader::helper('text');

		// Create subscriber
		$subscriber = new CcOptinSubscriber();
		$subscriber->campaignID = $id;
		$subscriber->email = $email;
		$subscriber->created = CcOptinDate::toMysqlUTC();
		$subscriber->ip = $th->sanitize($_SERVER['REMOTE_ADDR']);



		// Save subscriber data, which will trigger an error if it already exists for this campaign.
		try {
			$subscriber->save();
		} catch(\Doctrine\DBAL\DBALException $e) {
			return $this->outputJsonError(t('This email is already registered.'));
		}

		$campaign = new CcOptinCampaign();
		$campaign->load('id = ?', array($id));

		$tracker = new CcOptinCampaignTracker($campaign);
		$tracker->subscribe();

		// Return submitActions for processing on client-side, but skip the email data, it's serverside only.
		$actions = $campaign->submitActionsArray();

		if($actions['sendEmail']) {

			unset($actions['sendEmail']);
		}

		$this->outputJson($actions);
	}

}
