<?php 
namespace Concrete\Package\CcOptinFree\Models;

use Loader;

use Concrete\Package\CcOptinFree\CcOptin;

class CcOptinTemplate
{
	protected static $data = array(
		'simple' => array(
			'description' => 'Simple Green with e-mail',
			'types' => array(1),
			'designClass' => 1,
			'includeFields' => array('header', 'text', 'emailLabel', 'buttonText')
		),
		'silverlining' => array(
			'description' => 'Silver lining with e-mail',
			'types' => array(1),
			'designClass' => 1,
			'includeFields' => array('header', 'text', 'emailLabel', 'buttonText')
		),
		'winebox' => array(
			'description' => 'Wine box with e-mail',
			'types' => array(1),
			'designClass' => 1,
			'includeFields' => array('header', 'text', 'emailLabel', 'buttonText')
		)
	);

	public static function __staticConstruct() {
		$json = Loader::helper('json');
		$path = CcOptin::serverPath('templates/_data');

		if (is_dir($path) && ($dh = opendir($path))) {
			while (($file = readdir($dh)) !== false) {
				if(substr($file, -5) != '.json') continue;

				$data = $json->decode(file_get_contents($path . DIRECTORY_SEPARATOR . $file, FILE_TEXT), true);

				// In case we're at 5.6.1 which doesn't have json to array
				if (is_object($data))
					$data = self::object_to_array($data);

				self::$data = array_merge(self::$data, $data);
			}
			closedir($dh);
		}
	}

	private static function object_to_array($data) {
		if(is_array($data) || is_object($data)){
			$result = array();
			foreach($data as $key => $value){
				$result[$key] = self::object_to_array($value);
			}
			return $result;
		}
		return $data;
	}

	public static function listHandles($typeClass) {
		$output = array();
		foreach (self::$data as $handle => $fields) {
			if(in_array($typeClass, $fields['types']))
				$output[$handle] = $fields['description'];
		}
		asort($output);

		// After sorting on description, create the objects.
		foreach($output as $handle => $_) {
			$output[$handle] = self::get($handle);
		}

		return $output;
	}

	public static function get($handle) {
		if(is_string($handle) && array_key_exists($handle, self::$data))
			return new CcOptinTemplate($handle, self::$data[$handle]);
		else
			return null;
	}

	///// Common fields /////

	public $handle;						// Unique id
	public $description;				// Short description
	public $types; 						// List of compatible Types
	public $designClass;				// Compatible Design
	public $customContent = false;		// If false, a submitAction is required.
	public $parentHandle;				// If set, view.php and includeFields will be taken from there instead.
	public $includeFields;				// Design fields that should be editable

	private $parent;

	///// End common fields /////

	protected function __construct($handle, $params = null) {
		$this->handle = $handle;

		if(!$params) return;

		foreach ($params as $key => $val) {
			if (property_exists($this, $key)) {
				$this->$key = $val;
			}
		}

		if($this->parentHandle) {
			$this->parent = self::get($this->parentHandle);
			if(!$this->parent) throw new \Exception("No parent found: " . $this->parentHandle);
		}
	}

	///// Methods /////

	public function thumbnail() {
		return CcOptin::path('templates/' . $this->handle . '/thumbnail.png');
	}

	public function preview() {
		return CcOptin::path('templates/' . $this->handle . '/preview.jpg');
	}

	/**
	* To easily test if an edit field should be included in the view.
	*/
	public function includes($field) {
		$fields = $this->parent ? $this->parent->includeFields : $this->includeFields;
		return $fields === true || ($fields && in_array($field, $fields));
	}
}

CcOptinTemplate::__staticConstruct();
